# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
NLPlate module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_nlplate.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _NLPlate
else:
    import _NLPlate

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _NLPlate.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _NLPlate.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _NLPlate.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _NLPlate.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _NLPlate.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _NLPlate.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _NLPlate.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _NLPlate.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _NLPlate.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _NLPlate.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _NLPlate.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _NLPlate.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _NLPlate.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _NLPlate.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _NLPlate.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _NLPlate.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _NLPlate.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _NLPlate:
_NLPlate.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _NLPlate.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Plate
import OCC.Core.TColgp
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.Geom
import OCC.Core.GeomAbs

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_NLPlate_HGPPConstraint_Create() -> "opencascade::handle< NLPlate_HGPPConstraint >":
    return _NLPlate.Handle_NLPlate_HGPPConstraint_Create()

def Handle_NLPlate_HGPPConstraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HGPPConstraint >":
    return _NLPlate.Handle_NLPlate_HGPPConstraint_DownCast(t)

def Handle_NLPlate_HGPPConstraint_IsNull(t: "opencascade::handle< NLPlate_HGPPConstraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HGPPConstraint_IsNull(t)

def Handle_NLPlate_HPG0Constraint_Create() -> "opencascade::handle< NLPlate_HPG0Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0Constraint_Create()

def Handle_NLPlate_HPG0Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HPG0Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0Constraint_DownCast(t)

def Handle_NLPlate_HPG0Constraint_IsNull(t: "opencascade::handle< NLPlate_HPG0Constraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HPG0Constraint_IsNull(t)

def Handle_NLPlate_HPG1Constraint_Create() -> "opencascade::handle< NLPlate_HPG1Constraint >":
    return _NLPlate.Handle_NLPlate_HPG1Constraint_Create()

def Handle_NLPlate_HPG1Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HPG1Constraint >":
    return _NLPlate.Handle_NLPlate_HPG1Constraint_DownCast(t)

def Handle_NLPlate_HPG1Constraint_IsNull(t: "opencascade::handle< NLPlate_HPG1Constraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HPG1Constraint_IsNull(t)

def Handle_NLPlate_HPG0G1Constraint_Create() -> "opencascade::handle< NLPlate_HPG0G1Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0G1Constraint_Create()

def Handle_NLPlate_HPG0G1Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HPG0G1Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0G1Constraint_DownCast(t)

def Handle_NLPlate_HPG0G1Constraint_IsNull(t: "opencascade::handle< NLPlate_HPG0G1Constraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HPG0G1Constraint_IsNull(t)

def Handle_NLPlate_HPG2Constraint_Create() -> "opencascade::handle< NLPlate_HPG2Constraint >":
    return _NLPlate.Handle_NLPlate_HPG2Constraint_Create()

def Handle_NLPlate_HPG2Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HPG2Constraint >":
    return _NLPlate.Handle_NLPlate_HPG2Constraint_DownCast(t)

def Handle_NLPlate_HPG2Constraint_IsNull(t: "opencascade::handle< NLPlate_HPG2Constraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HPG2Constraint_IsNull(t)

def Handle_NLPlate_HPG0G2Constraint_Create() -> "opencascade::handle< NLPlate_HPG0G2Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0G2Constraint_Create()

def Handle_NLPlate_HPG0G2Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HPG0G2Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0G2Constraint_DownCast(t)

def Handle_NLPlate_HPG0G2Constraint_IsNull(t: "opencascade::handle< NLPlate_HPG0G2Constraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HPG0G2Constraint_IsNull(t)

def Handle_NLPlate_HPG3Constraint_Create() -> "opencascade::handle< NLPlate_HPG3Constraint >":
    return _NLPlate.Handle_NLPlate_HPG3Constraint_Create()

def Handle_NLPlate_HPG3Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HPG3Constraint >":
    return _NLPlate.Handle_NLPlate_HPG3Constraint_DownCast(t)

def Handle_NLPlate_HPG3Constraint_IsNull(t: "opencascade::handle< NLPlate_HPG3Constraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HPG3Constraint_IsNull(t)

def Handle_NLPlate_HPG0G3Constraint_Create() -> "opencascade::handle< NLPlate_HPG0G3Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0G3Constraint_Create()

def Handle_NLPlate_HPG0G3Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< NLPlate_HPG0G3Constraint >":
    return _NLPlate.Handle_NLPlate_HPG0G3Constraint_DownCast(t)

def Handle_NLPlate_HPG0G3Constraint_IsNull(t: "opencascade::handle< NLPlate_HPG0G3Constraint > const &") -> "bool":
    return _NLPlate.Handle_NLPlate_HPG0G3Constraint_IsNull(t)
class NLPlate_ListIteratorOfStackOfPlate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _NLPlate.NLPlate_ListIteratorOfStackOfPlate_swiginit(self, _NLPlate.new_NLPlate_ListIteratorOfStackOfPlate(*args))

    def More(self) -> "Standard_Boolean":
        return _NLPlate.NLPlate_ListIteratorOfStackOfPlate_More(self)

    def Next(self) -> "void":
        return _NLPlate.NLPlate_ListIteratorOfStackOfPlate_Next(self)

    def Value(self) -> "Plate_Plate const &":
        return _NLPlate.NLPlate_ListIteratorOfStackOfPlate_Value(self)

    def ChangeValue(self) -> "Plate_Plate &":
        return _NLPlate.NLPlate_ListIteratorOfStackOfPlate_ChangeValue(self)
    __swig_destroy__ = _NLPlate.delete_NLPlate_ListIteratorOfStackOfPlate

# Register NLPlate_ListIteratorOfStackOfPlate in _NLPlate:
_NLPlate.NLPlate_ListIteratorOfStackOfPlate_swigregister(NLPlate_ListIteratorOfStackOfPlate)

class NLPlate_SequenceOfHGPPConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< NLPlate_HGPPConstraint > >::iterator":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< NLPlate_HGPPConstraint > >::iterator":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< NLPlate_HGPPConstraint > >::const_iterator":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< NLPlate_HGPPConstraint > >::const_iterator":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_cend(self)

    def __init__(self, *args):
        _NLPlate.NLPlate_SequenceOfHGPPConstraint_swiginit(self, _NLPlate.new_NLPlate_SequenceOfHGPPConstraint(*args))

    def Size(self) -> "Standard_Integer":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_IsEmpty(self)

    def Reverse(self) -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Clear(self, theAllocator)

    def Assign(self, theOther: "NLPlate_SequenceOfHGPPConstraint") -> "NCollection_Sequence< opencascade::handle< NLPlate_HGPPConstraint > > &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Assign(self, theOther)

    def Set(self, theOther: "NLPlate_SequenceOfHGPPConstraint") -> "NCollection_Sequence< opencascade::handle< NLPlate_HGPPConstraint > > &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "NLPlate_SequenceOfHGPPConstraint") -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< NLPlate_HGPPConstraint > const &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_First(self)

    def ChangeFirst(self) -> "opencascade::handle< NLPlate_HGPPConstraint > &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< NLPlate_HGPPConstraint > const &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Last(self)

    def ChangeLast(self) -> "opencascade::handle< NLPlate_HGPPConstraint > &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< NLPlate_HGPPConstraint > const &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< NLPlate_HGPPConstraint > &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< NLPlate_HGPPConstraint > &":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< NLPlate_HGPPConstraint > const &") -> "void":
        return _NLPlate.NLPlate_SequenceOfHGPPConstraint_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _NLPlate.delete_NLPlate_SequenceOfHGPPConstraint

    def __len__(self):
        return self.Size()


# Register NLPlate_SequenceOfHGPPConstraint in _NLPlate:
_NLPlate.NLPlate_SequenceOfHGPPConstraint_swigregister(NLPlate_SequenceOfHGPPConstraint)

def NLPlate_SequenceOfHGPPConstraint_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _NLPlate.NLPlate_SequenceOfHGPPConstraint_delNode(theNode, theAl)

class NLPlate_StackOfPlate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< Plate_Plate >::iterator":
        return _NLPlate.NLPlate_StackOfPlate_begin(self)

    def end(self) -> "NCollection_List< Plate_Plate >::iterator":
        return _NLPlate.NLPlate_StackOfPlate_end(self)

    def cbegin(self) -> "NCollection_List< Plate_Plate >::const_iterator":
        return _NLPlate.NLPlate_StackOfPlate_cbegin(self)

    def cend(self) -> "NCollection_List< Plate_Plate >::const_iterator":
        return _NLPlate.NLPlate_StackOfPlate_cend(self)

    def __init__(self, *args):
        _NLPlate.NLPlate_StackOfPlate_swiginit(self, _NLPlate.new_NLPlate_StackOfPlate(*args))

    def Size(self) -> "Standard_Integer":
        return _NLPlate.NLPlate_StackOfPlate_Size(self)

    def Assign(self, theOther: "NLPlate_StackOfPlate") -> "NCollection_List< Plate_Plate > &":
        return _NLPlate.NLPlate_StackOfPlate_Assign(self, theOther)

    def Set(self, theOther: "NLPlate_StackOfPlate") -> "NCollection_List< Plate_Plate > &":
        return _NLPlate.NLPlate_StackOfPlate_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _NLPlate.NLPlate_StackOfPlate_Clear(self, theAllocator)

    def First(self) -> "Plate_Plate const &":
        return _NLPlate.NLPlate_StackOfPlate_First(self)

    def Last(self) -> "Plate_Plate const &":
        return _NLPlate.NLPlate_StackOfPlate_Last(self)

    def Append(self, *args) -> "void":
        return _NLPlate.NLPlate_StackOfPlate_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _NLPlate.NLPlate_StackOfPlate_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _NLPlate.NLPlate_StackOfPlate_RemoveFirst(self)

    def Remove(self, theIter: "NLPlate_ListIteratorOfStackOfPlate") -> "void":
        return _NLPlate.NLPlate_StackOfPlate_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _NLPlate.NLPlate_StackOfPlate_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _NLPlate.NLPlate_StackOfPlate_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _NLPlate.NLPlate_StackOfPlate_Reverse(self)
    __swig_destroy__ = _NLPlate.delete_NLPlate_StackOfPlate

    def __len__(self):
        return self.Size()


# Register NLPlate_StackOfPlate in _NLPlate:
_NLPlate.NLPlate_StackOfPlate_swigregister(NLPlate_StackOfPlate)

class NLPlate_HGPPConstraint(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def ActiveOrder(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _NLPlate.NLPlate_HGPPConstraint_ActiveOrder(self, *args)

    def G0Criterion(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _NLPlate.NLPlate_HGPPConstraint_G0Criterion(self, *args)

    def G0Target(self, *args) -> "gp_XYZ const":
        r"""
        No available documentation.

        Returns
        -------
        gp_XYZ

        """
        return _NLPlate.NLPlate_HGPPConstraint_G0Target(self, *args)

    def G1Criterion(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _NLPlate.NLPlate_HGPPConstraint_G1Criterion(self, *args)

    def G1Target(self, *args) -> "Plate_D1 const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_D1

        """
        return _NLPlate.NLPlate_HGPPConstraint_G1Target(self, *args)

    def G2Criterion(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _NLPlate.NLPlate_HGPPConstraint_G2Criterion(self, *args)

    def G2Target(self, *args) -> "Plate_D2 const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_D2

        """
        return _NLPlate.NLPlate_HGPPConstraint_G2Target(self, *args)

    def G3Criterion(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _NLPlate.NLPlate_HGPPConstraint_G3Criterion(self, *args)

    def G3Target(self, *args) -> "Plate_D3 const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_D3

        """
        return _NLPlate.NLPlate_HGPPConstraint_G3Target(self, *args)

    def IncrementalLoadAllowed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _NLPlate.NLPlate_HGPPConstraint_IncrementalLoadAllowed(self, *args)

    def IsG0(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _NLPlate.NLPlate_HGPPConstraint_IsG0(self, *args)

    def Orientation(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _NLPlate.NLPlate_HGPPConstraint_Orientation(self, *args)

    def SetActiveOrder(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ActiveOrder: int

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetActiveOrder(self, *args)

    def SetG0Criterion(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TolDist: float

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetG0Criterion(self, *args)

    def SetG1Criterion(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TolAng: float

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetG1Criterion(self, *args)

    def SetG2Criterion(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TolCurv: float

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetG2Criterion(self, *args)

    def SetG3Criterion(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TolG3: float

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetG3Criterion(self, *args)

    def SetIncrementalLoadAllowed(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ILA: bool

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetIncrementalLoadAllowed(self, *args)

    def SetOrientation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Orient: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetOrientation(self, *args)

    def SetUV(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetUV(self, *args)

    def SetUVFreeSliding(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        UVFree: bool

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_HGPPConstraint_SetUVFreeSliding(self, *args)

    def UV(self, *args) -> "gp_XY const":
        r"""
        No available documentation.

        Returns
        -------
        gp_XY

        """
        return _NLPlate.NLPlate_HGPPConstraint_UV(self, *args)

    def UVFreeSliding(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _NLPlate.NLPlate_HGPPConstraint_UVFreeSliding(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HGPPConstraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HGPPConstraint

# Register NLPlate_HGPPConstraint in _NLPlate:
_NLPlate.NLPlate_HGPPConstraint_swigregister(NLPlate_HGPPConstraint)

class NLPlate_NLPlate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        InitialSurface: Geom_Surface

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_NLPlate_swiginit(self, _NLPlate.new_NLPlate_NLPlate(*args))

    def ConstraintsSliding(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        NbIterations: int,optional
        	default value is 3

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_NLPlate_ConstraintsSliding(self, *args)

    def Continuity(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _NLPlate.NLPlate_NLPlate_Continuity(self, *args)

    def Evaluate(self, *args) -> "gp_XYZ":
        r"""
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY

        Returns
        -------
        gp_XYZ

        """
        return _NLPlate.NLPlate_NLPlate_Evaluate(self, *args)

    def EvaluateDerivative(self, *args) -> "gp_XYZ":
        r"""
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        iu: int
        iv: int

        Returns
        -------
        gp_XYZ

        """
        return _NLPlate.NLPlate_NLPlate_EvaluateDerivative(self, *args)

    def IncrementalSolve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ord: int,optional
        	default value is 2
        InitialConsraintOrder: int,optional
        	default value is 1
        NbIncrements: int,optional
        	default value is 4
        UVSliding: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_NLPlate_IncrementalSolve(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Reset the plate in the initial state ( same as after create((surface)).

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_NLPlate_Init(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if all has been correctly done.

        Returns
        -------
        bool

        """
        return _NLPlate.NLPlate_NLPlate_IsDone(self, *args)

    def Load(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        GConst: NLPlate_HGPPConstraint

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_NLPlate_Load(self, *args)

    def MaxActiveConstraintOrder(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _NLPlate.NLPlate_NLPlate_MaxActiveConstraintOrder(self, *args)

    def Solve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ord: int,optional
        	default value is 2
        InitialConsraintOrder: int,optional
        	default value is 1

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_NLPlate_Solve(self, *args)

    def Solve2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ord: int,optional
        	default value is 2
        InitialConsraintOrder: int,optional
        	default value is 1

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_NLPlate_Solve2(self, *args)

    def destroy(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _NLPlate.NLPlate_NLPlate_destroy(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_NLPlate

# Register NLPlate_NLPlate in _NLPlate:
_NLPlate.NLPlate_NLPlate_swigregister(NLPlate_NLPlate)

class NLPlate_HPG0Constraint(NLPlate_HGPPConstraint):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY
        Value: gp_XYZ

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_HPG0Constraint_swiginit(self, _NLPlate.new_NLPlate_HPG0Constraint(*args))


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HPG0Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HPG0Constraint

# Register NLPlate_HPG0Constraint in _NLPlate:
_NLPlate.NLPlate_HPG0Constraint_swigregister(NLPlate_HPG0Constraint)

class NLPlate_HPG1Constraint(NLPlate_HGPPConstraint):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY
        D1T: Plate_D1

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_HPG1Constraint_swiginit(self, _NLPlate.new_NLPlate_HPG1Constraint(*args))


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HPG1Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HPG1Constraint

# Register NLPlate_HPG1Constraint in _NLPlate:
_NLPlate.NLPlate_HPG1Constraint_swigregister(NLPlate_HPG1Constraint)

class NLPlate_HPG0G1Constraint(NLPlate_HPG0Constraint):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY
        Value: gp_XYZ
        D1T: Plate_D1

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_HPG0G1Constraint_swiginit(self, _NLPlate.new_NLPlate_HPG0G1Constraint(*args))


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HPG0G1Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HPG0G1Constraint

# Register NLPlate_HPG0G1Constraint in _NLPlate:
_NLPlate.NLPlate_HPG0G1Constraint_swigregister(NLPlate_HPG0G1Constraint)

class NLPlate_HPG2Constraint(NLPlate_HPG1Constraint):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY
        D1T: Plate_D1
        D2T: Plate_D2

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_HPG2Constraint_swiginit(self, _NLPlate.new_NLPlate_HPG2Constraint(*args))


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HPG2Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HPG2Constraint

# Register NLPlate_HPG2Constraint in _NLPlate:
_NLPlate.NLPlate_HPG2Constraint_swigregister(NLPlate_HPG2Constraint)

class NLPlate_HPG0G2Constraint(NLPlate_HPG0G1Constraint):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY
        Value: gp_XYZ
        D1T: Plate_D1
        D2T: Plate_D2

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_HPG0G2Constraint_swiginit(self, _NLPlate.new_NLPlate_HPG0G2Constraint(*args))


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HPG0G2Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HPG0G2Constraint

# Register NLPlate_HPG0G2Constraint in _NLPlate:
_NLPlate.NLPlate_HPG0G2Constraint_swigregister(NLPlate_HPG0G2Constraint)

class NLPlate_HPG3Constraint(NLPlate_HPG2Constraint):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY
        D1T: Plate_D1
        D2T: Plate_D2
        D3T: Plate_D3

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_HPG3Constraint_swiginit(self, _NLPlate.new_NLPlate_HPG3Constraint(*args))


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HPG3Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HPG3Constraint

# Register NLPlate_HPG3Constraint in _NLPlate:
_NLPlate.NLPlate_HPG3Constraint_swigregister(NLPlate_HPG3Constraint)

class NLPlate_HPG0G3Constraint(NLPlate_HPG0G2Constraint):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        UV: gp_XY
        Value: gp_XYZ
        D1T: Plate_D1
        D2T: Plate_D2
        D3T: Plate_D3

        Returns
        -------
        None

        """
        _NLPlate.NLPlate_HPG0G3Constraint_swiginit(self, _NLPlate.new_NLPlate_HPG0G3Constraint(*args))


    @staticmethod
    def DownCast(t):
      return Handle_NLPlate_HPG0G3Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _NLPlate.delete_NLPlate_HPG0G3Constraint

# Register NLPlate_HPG0G3Constraint in _NLPlate:
_NLPlate.NLPlate_HPG0G3Constraint_swigregister(NLPlate_HPG0G3Constraint)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Geom import *
from OCC.Core.gce import *


class GC_MakeMirror:
	@overload
	def __init__(self, Point: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax1) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin) -> None: ...
	@overload
	def __init__(self, Point: gp_Pnt, Direc: gp_Dir) -> None: ...
	@overload
	def __init__(self, Plane: gp_Pln) -> None: ...
	@overload
	def __init__(self, Plane: gp_Ax2) -> None: ...
	def Value(self) -> Geom_Transformation: ...

class GC_MakeRotation:
	@overload
	def __init__(self, Line: gp_Lin, Angle: float) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax1, Angle: float) -> None: ...
	@overload
	def __init__(self, Point: gp_Pnt, Direc: gp_Dir, Angle: float) -> None: ...
	def Value(self) -> Geom_Transformation: ...

class GC_MakeScale:
	def __init__(self, Point: gp_Pnt, Scale: float) -> None: ...
	def Value(self) -> Geom_Transformation: ...

class GC_MakeTranslation:
	@overload
	def __init__(self, Vect: gp_Vec) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt, Point2: gp_Pnt) -> None: ...
	def Value(self) -> Geom_Transformation: ...

class GC_Root:
	def IsDone(self) -> bool: ...
	def Status(self) -> gce_ErrorType: ...

class GC_MakeArcOfCircle(GC_Root):
	@overload
	def __init__(self, Circ: gp_Circ, Alpha1: float, Alpha2: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ, P: gp_Pnt, Alpha: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ, P1: gp_Pnt, P2: gp_Pnt, Sense: bool) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, V: gp_Vec, P2: gp_Pnt) -> None: ...
	def Value(self) -> Geom_TrimmedCurve: ...

class GC_MakeArcOfEllipse(GC_Root):
	@overload
	def __init__(self, Elips: gp_Elips, Alpha1: float, Alpha2: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Elips: gp_Elips, P: gp_Pnt, Alpha: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Elips: gp_Elips, P1: gp_Pnt, P2: gp_Pnt, Sense: bool) -> None: ...
	def Value(self) -> Geom_TrimmedCurve: ...

class GC_MakeArcOfHyperbola(GC_Root):
	@overload
	def __init__(self, Hypr: gp_Hypr, Alpha1: float, Alpha2: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Hypr: gp_Hypr, P: gp_Pnt, Alpha: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Hypr: gp_Hypr, P1: gp_Pnt, P2: gp_Pnt, Sense: bool) -> None: ...
	def Value(self) -> Geom_TrimmedCurve: ...

class GC_MakeArcOfParabola(GC_Root):
	@overload
	def __init__(self, Parab: gp_Parab, Alpha1: float, Alpha2: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Parab: gp_Parab, P: gp_Pnt, Alpha: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Parab: gp_Parab, P1: gp_Pnt, P2: gp_Pnt, Sense: bool) -> None: ...
	def Value(self) -> Geom_TrimmedCurve: ...

class GC_MakeCircle(GC_Root):
	@overload
	def __init__(self, C: gp_Circ) -> None: ...
	@overload
	def __init__(self, A2: gp_Ax2, Radius: float) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ, Dist: float) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ, Point: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt, Norm: gp_Dir, Radius: float) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt, PtAxis: gp_Pnt, Radius: float) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax1, Radius: float) -> None: ...
	def Value(self) -> Geom_Circle: ...

class GC_MakeConicalSurface(GC_Root):
	@overload
	def __init__(self, A2: gp_Ax2, Ang: float, Radius: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cone) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, P4: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, R1: float, R2: float) -> None: ...
	def Value(self) -> Geom_ConicalSurface: ...

class GC_MakeCylindricalSurface(GC_Root):
	@overload
	def __init__(self, A2: gp_Ax2, Radius: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, Point: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, Dist: float) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax1, Radius: float) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ) -> None: ...
	def Value(self) -> Geom_CylindricalSurface: ...

class GC_MakeEllipse(GC_Root):
	@overload
	def __init__(self, E: gp_Elips) -> None: ...
	@overload
	def __init__(self, A2: gp_Ax2, MajorRadius: float, MinorRadius: float) -> None: ...
	@overload
	def __init__(self, S1: gp_Pnt, S2: gp_Pnt, Center: gp_Pnt) -> None: ...
	def Value(self) -> Geom_Ellipse: ...

class GC_MakeHyperbola(GC_Root):
	@overload
	def __init__(self, H: gp_Hypr) -> None: ...
	@overload
	def __init__(self, A2: gp_Ax2, MajorRadius: float, MinorRadius: float) -> None: ...
	@overload
	def __init__(self, S1: gp_Pnt, S2: gp_Pnt, Center: gp_Pnt) -> None: ...
	def Value(self) -> Geom_Hyperbola: ...

class GC_MakeLine(GC_Root):
	@overload
	def __init__(self, A1: gp_Ax1) -> None: ...
	@overload
	def __init__(self, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, V: gp_Dir) -> None: ...
	@overload
	def __init__(self, Lin: gp_Lin, Point: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	def Value(self) -> Geom_Line: ...

class GC_MakePlane(GC_Root):
	@overload
	def __init__(self, Pl: gp_Pln) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, V: gp_Dir) -> None: ...
	@overload
	def __init__(self, A: float, B: float, C: float, D: float) -> None: ...
	@overload
	def __init__(self, Pln: gp_Pln, Point: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Pln: gp_Pln, Dist: float) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax1) -> None: ...
	def Value(self) -> Geom_Plane: ...

class GC_MakeSegment(GC_Root):
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin, U1: float, U2: float) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin, Point: gp_Pnt, Ulast: float) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	def Value(self) -> Geom_TrimmedCurve: ...

class GC_MakeTrimmedCone(GC_Root):
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, P4: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, R1: float, R2: float) -> None: ...
	def Value(self) -> Geom_RectangularTrimmedSurface: ...

class GC_MakeTrimmedCylinder(GC_Root):
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ, Height: float) -> None: ...
	@overload
	def __init__(self, A1: gp_Ax1, Radius: float, Height: float) -> None: ...
	def Value(self) -> Geom_RectangularTrimmedSurface: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.VrmlConverter import *
from OCC.Core.Vrml import *
from OCC.Core.Quantity import *
from OCC.Core.TDocStd import *


class VrmlAPI_RepresentationOfShape(IntEnum):
	VrmlAPI_ShadedRepresentation: int = ...
	VrmlAPI_WireFrameRepresentation: int = ...
	VrmlAPI_BothRepresentation: int = ...
VrmlAPI_ShadedRepresentation = VrmlAPI_RepresentationOfShape.VrmlAPI_ShadedRepresentation
VrmlAPI_WireFrameRepresentation = VrmlAPI_RepresentationOfShape.VrmlAPI_WireFrameRepresentation
VrmlAPI_BothRepresentation = VrmlAPI_RepresentationOfShape.VrmlAPI_BothRepresentation

class vrmlapi:
	@staticmethod
	def Write(aShape: TopoDS_Shape, aFileName: str, aVersion: Optional[int] = 2) -> bool: ...

class VrmlAPI_Writer:
	def __init__(self) -> None: ...
	def Drawer(self) -> VrmlConverter_Drawer: ...
	def GetFreeBoundsMaterial(self) -> Vrml_Material: ...
	def GetFrontMaterial(self) -> Vrml_Material: ...
	def GetLineMaterial(self) -> Vrml_Material: ...
	def GetPointsMaterial(self) -> Vrml_Material: ...
	def GetRepresentation(self) -> VrmlAPI_RepresentationOfShape: ...
	def GetUisoMaterial(self) -> Vrml_Material: ...
	def GetUnfreeBoundsMaterial(self) -> Vrml_Material: ...
	def GetVisoMaterial(self) -> Vrml_Material: ...
	def GetWireMaterial(self) -> Vrml_Material: ...
	def ResetToDefaults(self) -> None: ...
	def SetAmbientColorToMaterial(self, aMaterial: Vrml_Material, Color: Quantity_HArray1OfColor) -> None: ...
	def SetDeflection(self, aDef: float) -> None: ...
	def SetDiffuseColorToMaterial(self, aMaterial: Vrml_Material, Color: Quantity_HArray1OfColor) -> None: ...
	def SetEmissiveColorToMaterial(self, aMaterial: Vrml_Material, Color: Quantity_HArray1OfColor) -> None: ...
	def SetRepresentation(self, aRep: VrmlAPI_RepresentationOfShape) -> None: ...
	def SetShininessToMaterial(self, aMaterial: Vrml_Material, aShininess: float) -> None: ...
	def SetSpecularColorToMaterial(self, aMaterial: Vrml_Material, Color: Quantity_HArray1OfColor) -> None: ...
	def SetTransparencyToMaterial(self, aMaterial: Vrml_Material, aTransparency: float) -> None: ...
	def Write(self, aShape: TopoDS_Shape, aFile: str, aVersion: Optional[int] = 2) -> bool: ...
	def WriteDoc(self, theDoc: TDocStd_Document, theFile: str, theScale: float) -> bool: ...

# harray1 classes
# harray2 classes
# hsequence classes

vrmlapi_Write = vrmlapi.Write



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepClass module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepclass.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepClass
else:
    import _BRepClass

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepClass.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepClass.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepClass.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepClass.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepClass.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepClass.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepClass.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepClass.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepClass.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepClass.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepClass.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepClass.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepClass.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepClass.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepClass.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepClass.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepClass.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepClass:
_BRepClass.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepClass.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.IntRes2d
import OCC.Core.Geom2dInt
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.math
import OCC.Core.IntCurve
import OCC.Core.Extrema
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAdaptor
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH

from enum import IntEnum
from OCC.Core.Exception import *



class BRepClass_Edge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        None

        """
        _BRepClass.BRepClass_Edge_swiginit(self, _BRepClass.new_BRepClass_Edge(*args))

    def Edge(self, *args) -> "TopoDS_Edge":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepClass.BRepClass_Edge_Edge(self, *args)

    def Face(self, *args) -> "TopoDS_Face":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepClass.BRepClass_Edge_Face(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass.delete_BRepClass_Edge

# Register BRepClass_Edge in _BRepClass:
_BRepClass.BRepClass_Edge_swigregister(BRepClass_Edge)

class BRepClass_FClass2dOfFClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an undefined classifier.

        Returns
        -------
        None

        """
        _BRepClass.BRepClass_FClass2dOfFClassifier_swiginit(self, _BRepClass.new_BRepClass_FClass2dOfFClassifier(*args))

    def ClosestIntersection(self, *args) -> "Standard_Integer":
        r"""
        Returns 0 if the last compared edge had no relevant intersection. else returns the index of this intersection in the last intersection algorithm.

        Returns
        -------
        int

        """
        return _BRepClass.BRepClass_FClass2dOfFClassifier_ClosestIntersection(self, *args)

    def Compare(self, *args) -> "void":
        r"""
        Updates the classification process with the edge <e> from the boundary.

        Parameters
        ----------
        E: BRepClass_Edge
        Or: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FClass2dOfFClassifier_Compare(self, *args)

    def Intersector(self, *args) -> "BRepClass_Intersector &":
        r"""
        Returns the intersecting algorithm.

        Returns
        -------
        BRepClass_Intersector

        """
        return _BRepClass.BRepClass_FClass2dOfFClassifier_Intersector(self, *args)

    def IsHeadOrEnd(self, *args) -> "Standard_Boolean":
        r"""
        Returns the standard_true if the closest intersection point represents head or end of the edge. returns standard_false otherwise.

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FClass2dOfFClassifier_IsHeadOrEnd(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the current value of the parameter.

        Returns
        -------
        float

        """
        return _BRepClass.BRepClass_FClass2dOfFClassifier_Parameter(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Starts a classification process. the point to classify is the origin of the line <l>. <p> is the original length of the segment on <l> used to compute intersections. <tol> is the tolerance attached to the line segment in intersections.

        Parameters
        ----------
        L: gp_Lin2d
        P: float
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FClass2dOfFClassifier_Reset(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns the current state of the point.

        Returns
        -------
        TopAbs_State

        """
        return _BRepClass.BRepClass_FClass2dOfFClassifier_State(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass.delete_BRepClass_FClass2dOfFClassifier

# Register BRepClass_FClass2dOfFClassifier in _BRepClass:
_BRepClass.BRepClass_FClass2dOfFClassifier_swigregister(BRepClass_FClass2dOfFClassifier)

class BRepClass_FClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor, undefined algorithm.

        Returns
        -------
        None
        Creates an algorithm to classify the point p with tolerance <t> on the face described by <f>.

        Parameters
        ----------
        F: BRepClass_FaceExplorer
        P: gp_Pnt2d
        Tol: float

        Returns
        -------
        None

        """
        _BRepClass.BRepClass_FClassifier_swiginit(self, _BRepClass.new_BRepClass_FClassifier(*args))

    def Edge(self, *args) -> "BRepClass_Edge const &":
        r"""
        Returns the edge used to determine the classification. when the state is on this is the edge containing the point.

        Returns
        -------
        BRepClass_Edge

        """
        return _BRepClass.BRepClass_FClassifier_Edge(self, *args)

    def EdgeParameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on edge() used to determine the classification.

        Returns
        -------
        float

        """
        return _BRepClass.BRepClass_FClassifier_EdgeParameter(self, *args)

    def NoWires(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the face contains no wire. the state is in.

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FClassifier_NoWires(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Classify the point p with tolerance <t> on the face described by <f>.

        Parameters
        ----------
        F: BRepClass_FaceExplorer
        P: gp_Pnt2d
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FClassifier_Perform(self, *args)

    def Position(self, *args) -> "IntRes2d_Position":
        r"""
        Returns the position of the point on the edge returned by edge.

        Returns
        -------
        IntRes2d_Position

        """
        return _BRepClass.BRepClass_FClassifier_Position(self, *args)

    def Rejected(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when the state was computed by a rejection. the state is out.

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FClassifier_Rejected(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns the result of the classification.

        Returns
        -------
        TopAbs_State

        """
        return _BRepClass.BRepClass_FClassifier_State(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass.delete_BRepClass_FClassifier

# Register BRepClass_FClassifier in _BRepClass:
_BRepClass.BRepClass_FClassifier_swigregister(BRepClass_FClassifier)

class BRepClass_FaceExplorer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None

        """
        _BRepClass.BRepClass_FaceExplorer_swiginit(self, _BRepClass.new_BRepClass_FaceExplorer(*args))

    def CheckPoint(self, *args) -> "Standard_Boolean":
        r"""
        Checks the point and change its coords if it is located too far from the bounding box of the face. new coordinates of the point will be on the line between the point and the center of the bounding box. returns true if point was not changed.

        Parameters
        ----------
        thePoint: gp_Pnt2d

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FaceExplorer_CheckPoint(self, *args)

    def CurrentEdge(self, *args) -> "void":
        r"""
        Current edge in current wire and its orientation.

        Parameters
        ----------
        E: BRepClass_Edge
        Or: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FaceExplorer_CurrentEdge(self, *args)

    def InitEdges(self, *args) -> "void":
        r"""
        Starts an exploration of the edges of the current wire.

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FaceExplorer_InitEdges(self, *args)

    def InitWires(self, *args) -> "void":
        r"""
        Starts an exploration of the wires.

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FaceExplorer_InitWires(self, *args)

    def MoreEdges(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a current edge.

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FaceExplorer_MoreEdges(self, *args)

    def MoreWires(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a current wire.

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FaceExplorer_MoreWires(self, *args)

    def NextEdge(self, *args) -> "void":
        r"""
        Sets the explorer to the next edge.

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FaceExplorer_NextEdge(self, *args)

    def NextWire(self, *args) -> "void":
        r"""
        Sets the explorer to the next wire.

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FaceExplorer_NextWire(self, *args)

    def OtherSegment(self, *args) -> "Standard_Boolean":
        r"""
        Returns in <l>, <par> a segment having at least one intersection with the face boundary to compute intersections. each call gives another segment.

        Parameters
        ----------
        P: gp_Pnt2d
        L: gp_Lin2d

        Returns
        -------
        Par: float

        """
        return _BRepClass.BRepClass_FaceExplorer_OtherSegment(self, *args)

    def Reject(self, *args) -> "Standard_Boolean":
        r"""
        Should return true if the point is outside a bounding volume of the face.

        Parameters
        ----------
        P: gp_Pnt2d

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FaceExplorer_Reject(self, *args)

    def RejectEdge(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the edge bounding volume does not intersect the segment.

        Parameters
        ----------
        L: gp_Lin2d
        Par: float

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FaceExplorer_RejectEdge(self, *args)

    def RejectWire(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the wire bounding volume does not intersect the segment.

        Parameters
        ----------
        L: gp_Lin2d
        Par: float

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FaceExplorer_RejectWire(self, *args)

    def Segment(self, *args) -> "Standard_Boolean":
        r"""
        Returns in <l>, <par> a segment having at least one intersection with the face boundary to compute intersections.

        Parameters
        ----------
        P: gp_Pnt2d
        L: gp_Lin2d

        Returns
        -------
        Par: float

        """
        return _BRepClass.BRepClass_FaceExplorer_Segment(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass.delete_BRepClass_FaceExplorer

# Register BRepClass_FaceExplorer in _BRepClass:
_BRepClass.BRepClass_FaceExplorer_swigregister(BRepClass_FaceExplorer)

class BRepClass_FacePassiveClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an undefined classifier.

        Returns
        -------
        None

        """
        _BRepClass.BRepClass_FacePassiveClassifier_swiginit(self, _BRepClass.new_BRepClass_FacePassiveClassifier(*args))

    def ClosestIntersection(self, *args) -> "Standard_Integer":
        r"""
        Returns 0 if the last compared edge had no relevant intersection. else returns the index of this intersection in the last intersection algorithm.

        Returns
        -------
        int

        """
        return _BRepClass.BRepClass_FacePassiveClassifier_ClosestIntersection(self, *args)

    def Compare(self, *args) -> "void":
        r"""
        Updates the classification process with the edge <e> from the boundary.

        Parameters
        ----------
        E: BRepClass_Edge
        Or: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FacePassiveClassifier_Compare(self, *args)

    def Intersector(self, *args) -> "BRepClass_Intersector &":
        r"""
        Returns the intersecting algorithm.

        Returns
        -------
        BRepClass_Intersector

        """
        return _BRepClass.BRepClass_FacePassiveClassifier_Intersector(self, *args)

    def IsHeadOrEnd(self, *args) -> "Standard_Boolean":
        r"""
        Returns the standard_true if the closest intersection point represents head or end of the edge. returns standard_false otherwise.

        Returns
        -------
        bool

        """
        return _BRepClass.BRepClass_FacePassiveClassifier_IsHeadOrEnd(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the current value of the parameter.

        Returns
        -------
        float

        """
        return _BRepClass.BRepClass_FacePassiveClassifier_Parameter(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Starts a classification process. the point to classify is the origin of the line <l>. <p> is the original length of the segment on <l> used to compute intersections. <tol> is the tolerance attached to the line segment in intersections.

        Parameters
        ----------
        L: gp_Lin2d
        P: float
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FacePassiveClassifier_Reset(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns the current state of the point.

        Returns
        -------
        TopAbs_State

        """
        return _BRepClass.BRepClass_FacePassiveClassifier_State(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass.delete_BRepClass_FacePassiveClassifier

# Register BRepClass_FacePassiveClassifier in _BRepClass:
_BRepClass.BRepClass_FacePassiveClassifier_swigregister(BRepClass_FacePassiveClassifier)

class BRepClass_Intersector(OCC.Core.Geom2dInt.Geom2dInt_IntConicCurveOfGInter):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BRepClass.BRepClass_Intersector_swiginit(self, _BRepClass.new_BRepClass_Intersector(*args))

    def LocalGeometry(self, *args) -> "void":
        r"""
        Returns in <t>, <n> and <c> the tangent, normal and curvature of the edge <e> at parameter value <u>.

        Parameters
        ----------
        E: BRepClass_Edge
        U: float
        T: gp_Dir2d
        N: gp_Dir2d

        Returns
        -------
        C: float

        """
        return _BRepClass.BRepClass_Intersector_LocalGeometry(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Intersect the line segment and the edge.

        Parameters
        ----------
        L: gp_Lin2d
        P: float
        Tol: float
        E: BRepClass_Edge

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_Intersector_Perform(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass.delete_BRepClass_Intersector

# Register BRepClass_Intersector in _BRepClass:
_BRepClass.BRepClass_Intersector_swigregister(BRepClass_Intersector)

class BRepClass_FaceClassifier(BRepClass_FClassifier):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor, undefined algorithm.

        Returns
        -------
        None
        Creates an algorithm to classify the point p with tolerance <t> on the face described by <f>.

        Parameters
        ----------
        F: BRepClass_FaceExplorer
        P: gp_Pnt2d
        Tol: float

        Returns
        -------
        None
        Creates an algorithm to classify the point p with tolerance <t> on the face <f>.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt2d
        Tol: float

        Returns
        -------
        None
        Creates an algorithm to classify the point p with tolerance <t> on the face <f>.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt
        Tol: float

        Returns
        -------
        None

        """
        _BRepClass.BRepClass_FaceClassifier_swiginit(self, _BRepClass.new_BRepClass_FaceClassifier(*args))

    def Perform(self, *args) -> "void":
        r"""
        Classify the point p with tolerance <t> on the face described by <f>.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt2d
        Tol: float

        Returns
        -------
        None
        Classify the point p with tolerance <t> on the face described by <f>.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass.BRepClass_FaceClassifier_Perform(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass.delete_BRepClass_FaceClassifier

# Register BRepClass_FaceClassifier in _BRepClass:
_BRepClass.BRepClass_FaceClassifier_swigregister(BRepClass_FaceClassifier)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
STEPControl module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stepcontrol.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _STEPControl
else:
    import _STEPControl

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _STEPControl.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _STEPControl.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _STEPControl.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _STEPControl.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _STEPControl.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _STEPControl.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _STEPControl.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _STEPControl.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _STEPControl.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _STEPControl.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _STEPControl.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _STEPControl.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _STEPControl.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _STEPControl.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _STEPControl.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _STEPControl.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _STEPControl.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _STEPControl:
_STEPControl.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _STEPControl.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Transfer
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.Interface
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.StepRepr
import OCC.Core.StepData
import OCC.Core.Resource
import OCC.Core.StepBasic
import OCC.Core.StepGeom
import OCC.Core.StepShape
import OCC.Core.TopTools
import OCC.Core.XSControl
import OCC.Core.IFSelect
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *

STEPControl_AsIs = _STEPControl.STEPControl_AsIs
STEPControl_ManifoldSolidBrep = _STEPControl.STEPControl_ManifoldSolidBrep
STEPControl_BrepWithVoids = _STEPControl.STEPControl_BrepWithVoids
STEPControl_FacetedBrep = _STEPControl.STEPControl_FacetedBrep
STEPControl_FacetedBrepAndBrepWithVoids = _STEPControl.STEPControl_FacetedBrepAndBrepWithVoids
STEPControl_ShellBasedSurfaceModel = _STEPControl.STEPControl_ShellBasedSurfaceModel
STEPControl_GeometricCurveSet = _STEPControl.STEPControl_GeometricCurveSet
STEPControl_Hybrid = _STEPControl.STEPControl_Hybrid


class STEPControl_StepModelType(IntEnum):
	STEPControl_AsIs = 0
	STEPControl_ManifoldSolidBrep = 1
	STEPControl_BrepWithVoids = 2
	STEPControl_FacetedBrep = 3
	STEPControl_FacetedBrepAndBrepWithVoids = 4
	STEPControl_ShellBasedSurfaceModel = 5
	STEPControl_GeometricCurveSet = 6
	STEPControl_Hybrid = 7
STEPControl_AsIs = STEPControl_StepModelType.STEPControl_AsIs
STEPControl_ManifoldSolidBrep = STEPControl_StepModelType.STEPControl_ManifoldSolidBrep
STEPControl_BrepWithVoids = STEPControl_StepModelType.STEPControl_BrepWithVoids
STEPControl_FacetedBrep = STEPControl_StepModelType.STEPControl_FacetedBrep
STEPControl_FacetedBrepAndBrepWithVoids = STEPControl_StepModelType.STEPControl_FacetedBrepAndBrepWithVoids
STEPControl_ShellBasedSurfaceModel = STEPControl_StepModelType.STEPControl_ShellBasedSurfaceModel
STEPControl_GeometricCurveSet = STEPControl_StepModelType.STEPControl_GeometricCurveSet
STEPControl_Hybrid = STEPControl_StepModelType.STEPControl_Hybrid


def Handle_STEPControl_ActorRead_Create() -> "opencascade::handle< STEPControl_ActorRead >":
    return _STEPControl.Handle_STEPControl_ActorRead_Create()

def Handle_STEPControl_ActorRead_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPControl_ActorRead >":
    return _STEPControl.Handle_STEPControl_ActorRead_DownCast(t)

def Handle_STEPControl_ActorRead_IsNull(t: "opencascade::handle< STEPControl_ActorRead > const &") -> "bool":
    return _STEPControl.Handle_STEPControl_ActorRead_IsNull(t)

def Handle_STEPControl_ActorWrite_Create() -> "opencascade::handle< STEPControl_ActorWrite >":
    return _STEPControl.Handle_STEPControl_ActorWrite_Create()

def Handle_STEPControl_ActorWrite_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPControl_ActorWrite >":
    return _STEPControl.Handle_STEPControl_ActorWrite_DownCast(t)

def Handle_STEPControl_ActorWrite_IsNull(t: "opencascade::handle< STEPControl_ActorWrite > const &") -> "bool":
    return _STEPControl.Handle_STEPControl_ActorWrite_IsNull(t)

def Handle_STEPControl_Controller_Create() -> "opencascade::handle< STEPControl_Controller >":
    return _STEPControl.Handle_STEPControl_Controller_Create()

def Handle_STEPControl_Controller_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPControl_Controller >":
    return _STEPControl.Handle_STEPControl_Controller_DownCast(t)

def Handle_STEPControl_Controller_IsNull(t: "opencascade::handle< STEPControl_Controller > const &") -> "bool":
    return _STEPControl.Handle_STEPControl_Controller_IsNull(t)
class STEPControl_ActorRead(OCC.Core.Transfer.Transfer_ActorOfTransientProcess):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPControl.STEPControl_ActorRead_swiginit(self, _STEPControl.new_STEPControl_ActorRead(*args))

    def ComputeSRRWT(self, *args) -> "Standard_Boolean":
        r"""
        Computes transformation defined by given representation_relationship_with_transformation.

        Parameters
        ----------
        SRR: StepRepr_RepresentationRelationship
        TP: Transfer_TransientProcess
        Trsf: gp_Trsf

        Returns
        -------
        bool

        """
        return _STEPControl.STEPControl_ActorRead_ComputeSRRWT(self, *args)

    def ComputeTransformation(self, *args) -> "Standard_Boolean":
        r"""
        Computes transformation defined by two axis placements (in mapped_item or item_defined_transformation) taking into account their representation contexts (i.e. units, which may be different) returns true if transformation is computed and is not an identity.

        Parameters
        ----------
        Origin: StepGeom_Axis2Placement3d
        Target: StepGeom_Axis2Placement3d
        OrigContext: StepRepr_Representation
        TargContext: StepRepr_Representation
        TP: Transfer_TransientProcess
        Trsf: gp_Trsf

        Returns
        -------
        bool

        """
        return _STEPControl.STEPControl_ActorRead_ComputeTransformation(self, *args)

    def PrepareUnits(self, *args) -> "void":
        r"""
        Set units and tolerances context by given shaperepresentation.

        Parameters
        ----------
        rep: StepRepr_Representation
        TP: Transfer_TransientProcess

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_ActorRead_PrepareUnits(self, *args)

    def ResetUnits(self, *args) -> "void":
        r"""
        Reset units and tolerances context to default (mm, radians, read.precision.val, etc.).

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_ActorRead_ResetUnits(self, *args)

    def TransferShape(self, *args) -> "opencascade::handle< Transfer_Binder >":
        r"""
        Theusetrsf - special flag for using axis2placement from shaperepresentation for transform root shape.

        Parameters
        ----------
        start: Standard_Transient
        TP: Transfer_TransientProcess
        isManifold: bool,optional
        	default value is Standard_True
        theUseTrsf: bool,optional
        	default value is Standard_False
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<Transfer_Binder>

        """
        return _STEPControl.STEPControl_ActorRead_TransferShape(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_STEPControl_ActorRead_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPControl.delete_STEPControl_ActorRead

# Register STEPControl_ActorRead in _STEPControl:
_STEPControl.STEPControl_ActorRead_swigregister(STEPControl_ActorRead)

class STEPControl_ActorWrite(OCC.Core.Transfer.Transfer_ActorOfFinderProcess):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPControl.STEPControl_ActorWrite_swiginit(self, _STEPControl.new_STEPControl_ActorWrite(*args))

    def GroupMode(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPControl.STEPControl_ActorWrite_GroupMode(self, *args)

    def IsAssembly(self, *args) -> "Standard_Boolean":
        r"""
        Customizable method to check whether shape s should be written as assembly or not default implementation uses flag groupmode and analyses the shape itself note: this method can modify shape.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _STEPControl.STEPControl_ActorWrite_IsAssembly(self, *args)

    def Mode(self, *args) -> "STEPControl_StepModelType":
        r"""
        No available documentation.

        Returns
        -------
        STEPControl_StepModelType

        """
        return _STEPControl.STEPControl_ActorWrite_Mode(self, *args)

    def SetGroupMode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        mode: int

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_ActorWrite_SetGroupMode(self, *args)

    def SetMode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        M: STEPControl_StepModelType

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_ActorWrite_SetMode(self, *args)

    def SetTolerance(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_ActorWrite_SetTolerance(self, *args)

    def TransferCompound(self, *args) -> "opencascade::handle< Transfer_Binder >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: Transfer_Finder
        SDR: StepShape_ShapeDefinitionRepresentation
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<Transfer_Binder>

        """
        return _STEPControl.STEPControl_ActorWrite_TransferCompound(self, *args)

    def TransferShape(self, *args) -> "opencascade::handle< Transfer_Binder >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: Transfer_Finder
        SDR: StepShape_ShapeDefinitionRepresentation
        FP: Transfer_FinderProcess
        shapeGroup: TopTools_HSequenceOfShape,optional
        	default value is NULL
        isManifold: bool,optional
        	default value is Standard_True
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<Transfer_Binder>

        """
        return _STEPControl.STEPControl_ActorWrite_TransferShape(self, *args)

    def TransferSubShape(self, *args) -> "opencascade::handle< Transfer_Binder >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: Transfer_Finder
        SDR: StepShape_ShapeDefinitionRepresentation
        AX1: StepGeom_Axis2Placement3d
        FP: Transfer_FinderProcess
        shapeGroup: TopTools_HSequenceOfShape,optional
        	default value is NULL
        isManifold: bool,optional
        	default value is Standard_True
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<Transfer_Binder>

        """
        return _STEPControl.STEPControl_ActorWrite_TransferSubShape(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_STEPControl_ActorWrite_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPControl.delete_STEPControl_ActorWrite

# Register STEPControl_ActorWrite in _STEPControl:
_STEPControl.STEPControl_ActorWrite_swigregister(STEPControl_ActorWrite)

class STEPControl_Controller(OCC.Core.XSControl.XSControl_Controller):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the use of step norm (the first time) and returns a controller.

        Returns
        -------
        None

        """
        _STEPControl.STEPControl_Controller_swiginit(self, _STEPControl.new_STEPControl_Controller(*args))

    @staticmethod
    def Init(*args) -> "Standard_Boolean":
        r"""
        Standard initialisation. it creates a controller for step and records it to various names, available to select it later returns true when done, false if could not be done.

        Returns
        -------
        bool

        """
        return _STEPControl.STEPControl_Controller_Init(*args)


    @staticmethod
    def DownCast(t):
      return Handle_STEPControl_Controller_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPControl.delete_STEPControl_Controller

# Register STEPControl_Controller in _STEPControl:
_STEPControl.STEPControl_Controller_swigregister(STEPControl_Controller)

def STEPControl_Controller_Init(*args) -> "Standard_Boolean":
    r"""
    Standard initialisation. it creates a controller for step and records it to various names, available to select it later returns true when done, false if could not be done.

    Returns
    -------
    bool

    """
    return _STEPControl.STEPControl_Controller_Init(*args)

class STEPControl_Reader(OCC.Core.XSControl.XSControl_Reader):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a reader object with an empty step model.

        Returns
        -------
        None
        Creates a reader for step from an already existing session clears the session if it was not yet set for step.

        Parameters
        ----------
        WS: XSControl_WorkSession
        scratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _STEPControl.STEPControl_Reader_swiginit(self, _STEPControl.new_STEPControl_Reader(*args))

    def FileUnits(self, *args) -> "void":
        r"""
        Returns sequence of all unit names for shape representations found in file.

        Parameters
        ----------
        theUnitLengthNames: TColStd_SequenceOfAsciiString
        theUnitAngleNames: TColStd_SequenceOfAsciiString
        theUnitSolidAngleNames: TColStd_SequenceOfAsciiString

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_Reader_FileUnits(self, *args)

    def StepModel(self, *args) -> "opencascade::handle< StepData_StepModel >":
        r"""
        Returns the model as a stepmodel. it can then be consulted (header, product).

        Returns
        -------
        opencascade::handle<StepData_StepModel>

        """
        return _STEPControl.STEPControl_Reader_StepModel(self, *args)

    def TransferRoot(self, *args) -> "Standard_Boolean":
        r"""
        Transfers a root given its rank in the list of candidate roots default is the first one returns true if a shape has resulted, false else same as inherited transferoneroot, kept for compatibility.

        Parameters
        ----------
        num: int,optional
        	default value is 1
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _STEPControl.STEPControl_Reader_TransferRoot(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _STEPControl.delete_STEPControl_Reader

# Register STEPControl_Reader in _STEPControl:
_STEPControl.STEPControl_Reader_swigregister(STEPControl_Reader)

class STEPControl_Writer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a writer from scratch.

        Returns
        -------
        None
        Creates a writer from an already existing session if <scratch> is true (d), clears already recorded data.

        Parameters
        ----------
        WS: XSControl_WorkSession
        scratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _STEPControl.STEPControl_Writer_swiginit(self, _STEPControl.new_STEPControl_Writer(*args))

    def Model(self, *args) -> "opencascade::handle< StepData_StepModel >":
        r"""
        Returns the produced model. produces a new one if not yet done or if <newone> is true this method allows for instance to edit product or header data before writing.

        Parameters
        ----------
        newone: bool,optional
        	default value is Standard_False

        Returns
        -------
        opencascade::handle<StepData_StepModel>

        """
        return _STEPControl.STEPControl_Writer_Model(self, *args)

    def PrintStatsTransfer(self, *args) -> "void":
        r"""
        Displays the statistics for the last translation. what defines the kind of statistics that are displayed: - 0 gives general statistics (number of translated roots, number of warnings, number of fail messages), - 1 gives root results, - 2 gives statistics for all checked entities, - 3 gives the list of translated entities, - 4 gives warning and fail messages, - 5 gives fail messages only. mode is used according to the use of what. if what is 0, mode is ignored. if what is 1, 2 or 3, mode defines the following: - 0 lists the numbers of step entities in a step model, - 1 gives the number, identifier, type and result type for each step entity and/or its status (fail, warning, etc.), - 2 gives maximum information for each step entity (i.e. checks), - 3 gives the number of entities by the type of a step entity, - 4 gives the number of of step entities per result type and/or status, - 5 gives the number of pairs (step or result type and status), - 6 gives the number of pairs (step or result type and status) and the list of entity numbers in the step model.

        Parameters
        ----------
        what: int
        mode: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_Writer_PrintStatsTransfer(self, *args)

    def SetTolerance(self, *args) -> "void":
        r"""
        Sets a length-measure value that will be written to uncertainty-measure-with-unit when the next shape is translated.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_Writer_SetTolerance(self, *args)

    def SetWS(self, *args) -> "void":
        r"""
        Sets a specific session to <self>.

        Parameters
        ----------
        WS: XSControl_WorkSession
        scratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_Writer_SetWS(self, *args)

    def Transfer(self, *args) -> "IFSelect_ReturnStatus":
        r"""
        Translates shape sh to a step entity. mode defines the step entity type to be output: - stepcontrolstd_asis translates a shape to its highest possible step representation. - stepcontrolstd_manifoldsolidbrep translates a shape to a step manifold_solid_brep or brep_with_voids entity. - stepcontrolstd_facetedbrep translates a shape into a step faceted_brep entity. - stepcontrolstd_shellbasedsurfacemodel translates a shape into a step shell_based_surface_model entity. - stepcontrolstd_geometriccurveset translates a shape into a step geometric_curve_set entity.

        Parameters
        ----------
        sh: TopoDS_Shape
        mode: STEPControl_StepModelType
        compgraph: bool,optional
        	default value is Standard_True
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        IFSelect_ReturnStatus

        """
        return _STEPControl.STEPControl_Writer_Transfer(self, *args)

    def UnsetTolerance(self, *args) -> "void":
        r"""
        Unsets the tolerance formerly forced by settolerance.

        Returns
        -------
        None

        """
        return _STEPControl.STEPControl_Writer_UnsetTolerance(self, *args)

    def WS(self, *args) -> "opencascade::handle< XSControl_WorkSession >":
        r"""
        Returns the session used in <self>.

        Returns
        -------
        opencascade::handle<XSControl_WorkSession>

        """
        return _STEPControl.STEPControl_Writer_WS(self, *args)

    def Write(self, *args) -> "IFSelect_ReturnStatus":
        r"""
        Writes a step model in the file identified by filename.

        Parameters
        ----------
        filename: char *

        Returns
        -------
        IFSelect_ReturnStatus

        """
        return _STEPControl.STEPControl_Writer_Write(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _STEPControl.delete_STEPControl_Writer

# Register STEPControl_Writer in _STEPControl:
_STEPControl.STEPControl_Writer_swigregister(STEPControl_Writer)





